@@ -1,5 +1,5 @@
-extern crate sysctl;
 extern crate libc;
+extern crate sysctl;
 
 use libc::c_int;
 use std::fmt;
@@ -8,7 +8,7 @@ use std::fmt;
 #[derive(Debug)]
 #[repr(C)]
 struct ClockInfo {
-    hz: c_int, /* clock frequency */
+    hz: c_int,   /* clock frequency */
     tick: c_int, /* micro-seconds per hz tick */
     spare: c_int,
     stathz: c_int, /* statistics clock frequency */
@@ -24,11 +24,13 @@ struct LoadAvg {
 impl fmt::Debug for LoadAvg {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         let s = self.fscale as f32;
-        write!(f,
-               "LoadAvg {{ {:.2} {:.2} {:.2} }}",
-               self.ldavg[0] as f32 / s,
-               self.ldavg[1] as f32 / s,
-               self.ldavg[2] as f32 / s)
+        write!(
+            f,
+            "LoadAvg {{ {:.2} {:.2} {:.2} }}",
+            self.ldavg[0] as f32 / s,
+            self.ldavg[1] as f32 / s,
+            self.ldavg[2] as f32 / s
+        )
     }
 }
 
